Class: Google::Apps::Card::V1::Card::CardAction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/card/v1/card.rb

Overview

A card action is the action associated with the card. For example, an invoice card might include actions such as delete invoice, email invoice, or open the invoice in a browser.

Google Workspace add-ons:

Instance Attribute Summary collapse

Instance Attribute Details

#action_label ⇒ ::String

Returns The label that displays as the action menu item.

Returns:

  • (::String) —

    The label that displays as the action menu item.



314
315
316
317
# File 'proto_docs/google/apps/card/v1/card.rb', line 314

class CardAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#on_click ⇒ ::Google::Apps::Card::V1::OnClick

Returns The onClick action for this action item.

Returns:



314
315
316
317
# File 'proto_docs/google/apps/card/v1/card.rb', line 314

class CardAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end