Class: Google::Apps::Card::V1::Card::CardHeader

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/card/v1/card.rb

Overview

Represents a card header. For an example in Google Chat apps, see Add a header.

Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Attribute Details

#image_alt_text::String

Returns The alternative text of this image that's used for accessibility.

Returns:

  • (::String)

    The alternative text of this image that's used for accessibility.



247
248
249
250
# File 'proto_docs/google/apps/card/v1/card.rb', line 247

class CardHeader
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_type::Google::Apps::Card::V1::Widget::ImageType

Returns The shape used to crop the image.

Google Workspace add-ons and Chat apps:.



247
248
249
250
# File 'proto_docs/google/apps/card/v1/card.rb', line 247

class CardHeader
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_url::String

Returns The HTTPS URL of the image in the card header.

Returns:

  • (::String)

    The HTTPS URL of the image in the card header.



247
248
249
250
# File 'proto_docs/google/apps/card/v1/card.rb', line 247

class CardHeader
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subtitle::String

Returns The subtitle of the card header. If specified, appears on its own line below the title.

Returns:

  • (::String)

    The subtitle of the card header. If specified, appears on its own line below the title.



247
248
249
250
# File 'proto_docs/google/apps/card/v1/card.rb', line 247

class CardHeader
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#title::String

Returns Required. The title of the card header. The header has a fixed height: if both a title and subtitle are specified, each takes up one line. If only the title is specified, it takes up both lines.

Returns:

  • (::String)

    Required. The title of the card header. The header has a fixed height: if both a title and subtitle are specified, each takes up one line. If only the title is specified, it takes up both lines.



247
248
249
250
# File 'proto_docs/google/apps/card/v1/card.rb', line 247

class CardHeader
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end