Module: Google::Apps::Card::V1::Card::DisplayStyle

Defined in:
proto_docs/google/apps/card/v1/card.rb

Overview

In Google Workspace add-ons, determines how a card is displayed.

Google Workspace add-ons:

Constant Summary collapse

DISPLAY_STYLE_UNSPECIFIED =

Don't use. Unspecified.

0
PEEK =

The header of the card appears at the bottom of the sidebar, partially covering the current top card of the stack. Clicking the header pops the card into the card stack. If the card has no header, a generated header is used instead.

1
REPLACE =

Default value. The card is shown by replacing the view of the top card in the card stack.

2