Class: Google::Apps::Card::V1::Carousel
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::Carousel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
A carousel, also known as a slider, rotates and displays a list of widgets in a slideshow format, with buttons navigating to the previous or next widget.
For example, this is a JSON representation of a carousel that contains three text paragraph widgets.
{
"carouselCards": [
{
"widgets": [
{
"textParagraph": {
"text": "First text paragraph in carousel",
}
}
]
},
{
"widgets": [
{
"textParagraph": {
"text": "Second text paragraph in carousel",
}
}
]
},
{
"widgets": [
{
"textParagraph": {
"text": "Third text paragraph in carousel",
}
}
]
}
]
}
Defined Under Namespace
Classes: CarouselCard
Instance Attribute Summary collapse
-
#carousel_cards ⇒ ::Array<::Google::Apps::Card::V1::Carousel::CarouselCard>
A list of cards included in the carousel.
Instance Attribute Details
#carousel_cards ⇒ ::Array<::Google::Apps::Card::V1::Carousel::CarouselCard>
Returns A list of cards included in the carousel.
2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 2214 class Carousel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A card that can be displayed as a carousel item. # [Google Chat apps](https://developers.google.com/workspace/chat): # @!attribute [rw] widgets # @return [::Array<::Google::Apps::Card::V1::Card::NestedWidget>] # A list of widgets displayed in the carousel card. The widgets are # displayed in the order that they are specified. # @!attribute [rw] footer_widgets # @return [::Array<::Google::Apps::Card::V1::Card::NestedWidget>] # A list of widgets displayed at the bottom of the carousel card. The # widgets are displayed in the order that they are specified. class CarouselCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |