Class: Google::Apps::Card::V1::Columns::Column::Widgets

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/card/v1/card.rb

Overview

The supported widgets that you can include in a column.

Google Workspace add-ons and Chat apps

Instance Attribute Summary collapse

Instance Attribute Details

#button_list ⇒ ::Google::Apps::Card::V1::ButtonList

Returns ButtonList widget.

Note: The following fields are mutually exclusive: button_list, text_paragraph, image, decorated_text, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::ButtonList) —

    ButtonList widget.

    Note: The following fields are mutually exclusive: button_list, text_paragraph, image, decorated_text, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#chip_list ⇒ ::Google::Apps::Card::V1::ChipList

Returns ChipList widget.

Note: The following fields are mutually exclusive: chip_list, text_paragraph, image, decorated_text, button_list, text_input, selection_input, date_time_picker. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::ChipList) —

    ChipList widget.

    Note: The following fields are mutually exclusive: chip_list, text_paragraph, image, decorated_text, button_list, text_input, selection_input, date_time_picker. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#date_time_picker ⇒ ::Google::Apps::Card::V1::DateTimePicker

Returns DateTimePicker widget.

Note: The following fields are mutually exclusive: date_time_picker, text_paragraph, image, decorated_text, button_list, text_input, selection_input, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::DateTimePicker) —

    DateTimePicker widget.

    Note: The following fields are mutually exclusive: date_time_picker, text_paragraph, image, decorated_text, button_list, text_input, selection_input, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#decorated_text ⇒ ::Google::Apps::Card::V1::DecoratedText

Returns DecoratedText widget.

Note: The following fields are mutually exclusive: decorated_text, text_paragraph, image, button_list, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::DecoratedText) —

    DecoratedText widget.

    Note: The following fields are mutually exclusive: decorated_text, text_paragraph, image, button_list, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image ⇒ ::Google::Apps::Card::V1::Image

Returns Image widget.

Note: The following fields are mutually exclusive: image, text_paragraph, decorated_text, button_list, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::Image) —

    Image widget.

    Note: The following fields are mutually exclusive: image, text_paragraph, decorated_text, button_list, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#selection_input ⇒ ::Google::Apps::Card::V1::SelectionInput

Returns SelectionInput widget.

Note: The following fields are mutually exclusive: selection_input, text_paragraph, image, decorated_text, button_list, text_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::SelectionInput) —

    SelectionInput widget.

    Note: The following fields are mutually exclusive: selection_input, text_paragraph, image, decorated_text, button_list, text_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_input ⇒ ::Google::Apps::Card::V1::TextInput

Returns TextInput widget.

Note: The following fields are mutually exclusive: text_input, text_paragraph, image, decorated_text, button_list, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::TextInput) —

    TextInput widget.

    Note: The following fields are mutually exclusive: text_input, text_paragraph, image, decorated_text, button_list, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_paragraph ⇒ ::Google::Apps::Card::V1::TextParagraph

Returns TextParagraph widget.

Note: The following fields are mutually exclusive: text_paragraph, image, decorated_text, button_list, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Apps::Card::V1::TextParagraph) —

    TextParagraph widget.

    Note: The following fields are mutually exclusive: text_paragraph, image, decorated_text, button_list, text_input, selection_input, date_time_picker, chip_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



2124
2125
2126
2127
# File 'proto_docs/google/apps/card/v1/card.rb', line 2124

class Widgets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end