Class: Google::Apps::Card::V1::DateTimePicker

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/card/v1/card.rb

Overview

Lets users input a date, a time, or both a date and a time. Supports form submission validation. When Action.all_widgets_are_required is set to true or this widget is specified in Action.required_widgets, the submission action is blocked unless a value is selected. For an example in Google Chat apps, see Let a user pick a date and time.

Users can input text or use the picker to select dates and times. If users input an invalid date or time, the picker shows an error that prompts users to input the information correctly.

Google Workspace add-ons and Chat apps:

Defined Under Namespace

Modules: DateTimePickerType

Instance Attribute Summary collapse

Instance Attribute Details

#label ⇒ ::String



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'proto_docs/google/apps/card/v1/card.rb', line 1485

class DateTimePicker
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format for the date and time in the `DateTimePicker` widget.
  # Determines whether users can input a date, a time, or both a date and time.
  #
  # [Google Workspace add-ons and Chat
  # apps](https://developers.google.com/workspace/extend):
  module DateTimePickerType
    # Users input a date and time.
    DATE_AND_TIME = 0

    # Users input a date.
    DATE_ONLY = 1

    # Users input a time.
    TIME_ONLY = 2
  end
end

#name ⇒ ::String



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'proto_docs/google/apps/card/v1/card.rb', line 1485

class DateTimePicker
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format for the date and time in the `DateTimePicker` widget.
  # Determines whether users can input a date, a time, or both a date and time.
  #
  # [Google Workspace add-ons and Chat
  # apps](https://developers.google.com/workspace/extend):
  module DateTimePickerType
    # Users input a date and time.
    DATE_AND_TIME = 0

    # Users input a date.
    DATE_ONLY = 1

    # Users input a time.
    TIME_ONLY = 2
  end
end

#on_change_action ⇒ ::Google::Apps::Card::V1::Action



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'proto_docs/google/apps/card/v1/card.rb', line 1485

class DateTimePicker
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format for the date and time in the `DateTimePicker` widget.
  # Determines whether users can input a date, a time, or both a date and time.
  #
  # [Google Workspace add-ons and Chat
  # apps](https://developers.google.com/workspace/extend):
  module DateTimePickerType
    # Users input a date and time.
    DATE_AND_TIME = 0

    # Users input a date.
    DATE_ONLY = 1

    # Users input a time.
    TIME_ONLY = 2
  end
end

#timezone_offset_date ⇒ ::Integer



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'proto_docs/google/apps/card/v1/card.rb', line 1485

class DateTimePicker
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format for the date and time in the `DateTimePicker` widget.
  # Determines whether users can input a date, a time, or both a date and time.
  #
  # [Google Workspace add-ons and Chat
  # apps](https://developers.google.com/workspace/extend):
  module DateTimePickerType
    # Users input a date and time.
    DATE_AND_TIME = 0

    # Users input a date.
    DATE_ONLY = 1

    # Users input a time.
    TIME_ONLY = 2
  end
end

#type ⇒ ::Google::Apps::Card::V1::DateTimePicker::DateTimePickerType



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'proto_docs/google/apps/card/v1/card.rb', line 1485

class DateTimePicker
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format for the date and time in the `DateTimePicker` widget.
  # Determines whether users can input a date, a time, or both a date and time.
  #
  # [Google Workspace add-ons and Chat
  # apps](https://developers.google.com/workspace/extend):
  module DateTimePickerType
    # Users input a date and time.
    DATE_AND_TIME = 0

    # Users input a date.
    DATE_ONLY = 1

    # Users input a time.
    TIME_ONLY = 2
  end
end

#value_ms_epoch ⇒ ::Integer



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'proto_docs/google/apps/card/v1/card.rb', line 1485

class DateTimePicker
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format for the date and time in the `DateTimePicker` widget.
  # Determines whether users can input a date, a time, or both a date and time.
  #
  # [Google Workspace add-ons and Chat
  # apps](https://developers.google.com/workspace/extend):
  module DateTimePickerType
    # Users input a date and time.
    DATE_AND_TIME = 0

    # Users input a date.
    DATE_ONLY = 1

    # Users input a time.
    TIME_ONLY = 2
  end
end