Class: Google::Apps::Card::V1::DecoratedText::SwitchControl
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::DecoratedText::SwitchControl
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
Either a toggle-style switch or a checkbox inside a decoratedText widget.
Google Workspace add-ons and Chat apps:
Only supported in the decoratedText widget.
Defined Under Namespace
Modules: ControlType
Instance Attribute Summary collapse
-
#control_type ⇒ ::Google::Apps::Card::V1::DecoratedText::SwitchControl::ControlType
How the switch appears in the user interface.
-
#name ⇒ ::String
The name by which the switch widget is identified in a form input event.
-
#on_change_action ⇒ ::Google::Apps::Card::V1::Action
The action to perform when the switch state is changed, such as what function to run.
-
#selected ⇒ ::Boolean
When
true, the switch is selected. -
#value ⇒ ::String
The value entered by a user, returned as part of a form input event.
Instance Attribute Details
#control_type ⇒ ::Google::Apps::Card::V1::DecoratedText::SwitchControl::ControlType
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1030 class SwitchControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How the switch appears in the user interface. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module ControlType # A toggle-style switch. SWITCH = 0 # Deprecated in favor of `CHECK_BOX`. CHECKBOX = 1 # A checkbox. CHECK_BOX = 2 end end |
#name ⇒ ::String
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1030 class SwitchControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How the switch appears in the user interface. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module ControlType # A toggle-style switch. SWITCH = 0 # Deprecated in favor of `CHECK_BOX`. CHECKBOX = 1 # A checkbox. CHECK_BOX = 2 end end |
#on_change_action ⇒ ::Google::Apps::Card::V1::Action
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1030 class SwitchControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How the switch appears in the user interface. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module ControlType # A toggle-style switch. SWITCH = 0 # Deprecated in favor of `CHECK_BOX`. CHECKBOX = 1 # A checkbox. CHECK_BOX = 2 end end |
#selected ⇒ ::Boolean
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1030 class SwitchControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How the switch appears in the user interface. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module ControlType # A toggle-style switch. SWITCH = 0 # Deprecated in favor of `CHECK_BOX`. CHECKBOX = 1 # A checkbox. CHECK_BOX = 2 end end |
#value ⇒ ::String
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1030 class SwitchControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How the switch appears in the user interface. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module ControlType # A toggle-style switch. SWITCH = 0 # Deprecated in favor of `CHECK_BOX`. CHECKBOX = 1 # A checkbox. CHECK_BOX = 2 end end |