Class: Google::Apps::Card::V1::OpenLink

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/card/v1/card.rb

Overview

Represents an onClick event that opens a hyperlink.

Google Workspace add-ons and Chat apps:

Defined Under Namespace

Modules: OnClose, OpenAs

Instance Attribute Summary collapse

Instance Attribute Details

#on_close::Google::Apps::Card::V1::OpenLink::OnClose

Returns Whether the client forgets about a link after opening it, or observes it until the window closes.

Google Workspace add-ons:.

Returns:



2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
# File 'proto_docs/google/apps/card/v1/card.rb', line 2322

class OpenLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # When an `OnClick` action opens a link, then the client can either open it
  # as a full-size window (if that's the frame used by the client), or an
  # overlay (such as a pop-up). The implementation depends on the client
  # platform capabilities, and the value selected might be ignored if the
  # client doesn't support it. `FULL_SIZE` is supported by all clients.
  #
  # [Google Workspace
  # add-ons](https://developers.google.com/workspace/add-ons):
  module OpenAs
    # The link opens as a full-size window (if that's the frame used by the
    # client).
    FULL_SIZE = 0

    # The link opens as an overlay, such as a pop-up.
    OVERLAY = 1
  end

  # What the client does when a link opened by an `OnClick` action is closed.
  #
  # Implementation depends on client platform capabilities. For example, a web
  # browser might open a link in a pop-up window with an `OnClose` handler.
  #
  # If both `OnOpen` and `OnClose` handlers are set, and the client platform
  # can't support both values, `OnClose` takes precedence.
  #
  # [Google Workspace
  # add-ons](https://developers.google.com/workspace/add-ons):
  module OnClose
    # Default value. The card doesn't reload; nothing happens.
    NOTHING = 0

    # Reloads the card after the child window closes.
    #
    # If used in conjunction with
    # [`OpenAs.OVERLAY`](https://developers.google.com/workspace/add-ons/reference/rpc/google.apps.card.v1#openas),
    # the child window acts as a modal dialog and the parent card is blocked
    # until the child window closes.
    RELOAD = 1
  end
end

#open_as::Google::Apps::Card::V1::OpenLink::OpenAs

Returns How to open a link.

Google Workspace add-ons:.



2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
# File 'proto_docs/google/apps/card/v1/card.rb', line 2322

class OpenLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # When an `OnClick` action opens a link, then the client can either open it
  # as a full-size window (if that's the frame used by the client), or an
  # overlay (such as a pop-up). The implementation depends on the client
  # platform capabilities, and the value selected might be ignored if the
  # client doesn't support it. `FULL_SIZE` is supported by all clients.
  #
  # [Google Workspace
  # add-ons](https://developers.google.com/workspace/add-ons):
  module OpenAs
    # The link opens as a full-size window (if that's the frame used by the
    # client).
    FULL_SIZE = 0

    # The link opens as an overlay, such as a pop-up.
    OVERLAY = 1
  end

  # What the client does when a link opened by an `OnClick` action is closed.
  #
  # Implementation depends on client platform capabilities. For example, a web
  # browser might open a link in a pop-up window with an `OnClose` handler.
  #
  # If both `OnOpen` and `OnClose` handlers are set, and the client platform
  # can't support both values, `OnClose` takes precedence.
  #
  # [Google Workspace
  # add-ons](https://developers.google.com/workspace/add-ons):
  module OnClose
    # Default value. The card doesn't reload; nothing happens.
    NOTHING = 0

    # Reloads the card after the child window closes.
    #
    # If used in conjunction with
    # [`OpenAs.OVERLAY`](https://developers.google.com/workspace/add-ons/reference/rpc/google.apps.card.v1#openas),
    # the child window acts as a modal dialog and the parent card is blocked
    # until the child window closes.
    RELOAD = 1
  end
end

#url::String

Returns The URL to open.

Returns:

  • (::String)

    The URL to open.



2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
# File 'proto_docs/google/apps/card/v1/card.rb', line 2322

class OpenLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # When an `OnClick` action opens a link, then the client can either open it
  # as a full-size window (if that's the frame used by the client), or an
  # overlay (such as a pop-up). The implementation depends on the client
  # platform capabilities, and the value selected might be ignored if the
  # client doesn't support it. `FULL_SIZE` is supported by all clients.
  #
  # [Google Workspace
  # add-ons](https://developers.google.com/workspace/add-ons):
  module OpenAs
    # The link opens as a full-size window (if that's the frame used by the
    # client).
    FULL_SIZE = 0

    # The link opens as an overlay, such as a pop-up.
    OVERLAY = 1
  end

  # What the client does when a link opened by an `OnClick` action is closed.
  #
  # Implementation depends on client platform capabilities. For example, a web
  # browser might open a link in a pop-up window with an `OnClose` handler.
  #
  # If both `OnOpen` and `OnClose` handlers are set, and the client platform
  # can't support both values, `OnClose` takes precedence.
  #
  # [Google Workspace
  # add-ons](https://developers.google.com/workspace/add-ons):
  module OnClose
    # Default value. The card doesn't reload; nothing happens.
    NOTHING = 0

    # Reloads the card after the child window closes.
    #
    # If used in conjunction with
    # [`OpenAs.OVERLAY`](https://developers.google.com/workspace/add-ons/reference/rpc/google.apps.card.v1#openas),
    # the child window acts as a modal dialog and the parent card is blocked
    # until the child window closes.
    RELOAD = 1
  end
end