Class: Google::Apps::Card::V1::OverflowMenu
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::OverflowMenu
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
A widget that presents a pop-up menu with one or more actions that users can
invoke. For example, showing non-primary actions in a card. You can use this
widget when actions don't fit in the available space. To use, specify this
widget in the OnClick action of widgets that support it. For example, in a
Button.
Defined Under Namespace
Classes: OverflowMenuItem
Instance Attribute Summary collapse
Instance Attribute Details
#items ⇒ ::Array<::Google::Apps::Card::V1::OverflowMenu::OverflowMenuItem>
Returns Required. The list of menu options.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1517 class OverflowMenu include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An option that users can invoke in an overflow menu. # # [Google Workspace add-ons and Chat # apps](https://developers.google.com/workspace/extend): # @!attribute [rw] start_icon # @return [::Google::Apps::Card::V1::Icon] # The icon displayed in front of the text. # @!attribute [rw] text # @return [::String] # Required. The text that identifies or describes the item to users. # @!attribute [rw] on_click # @return [::Google::Apps::Card::V1::OnClick] # Required. The action invoked when a menu option is selected. # This `OnClick` cannot contain an `OverflowMenu`, any specified # `OverflowMenu` is dropped and the menu item disabled. # @!attribute [rw] disabled # @return [::Boolean] # Whether the menu option is disabled. # Defaults to false. class OverflowMenuItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |