Class: Google::Apps::Chat::V1::AppCommandMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/app_command_metadata.rb

Overview

Metadata about a Chat app command.

Defined Under Namespace

Modules: AppCommandType

Instance Attribute Summary collapse

Instance Attribute Details

#app_command_id ⇒ ::Integer

Returns The ID for the command specified in the Chat API configuration.

Returns:

  • (::Integer) —

    The ID for the command specified in the Chat API configuration.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'proto_docs/google/chat/v1/app_command_metadata.rb', line 32

class AppCommandMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of Chat app command. For details, see [Types of Chat
  # app commands](https://developers.google.com/workspace/chat/commands#types).
  module AppCommandType
    # Default value. Unspecified.
    APP_COMMAND_TYPE_UNSPECIFIED = 0

    # A slash command. The user sends the command in a Chat message.
    SLASH_COMMAND = 1

    # A quick command. The user selects the command from the Chat menu
    # in the message reply area.
    QUICK_COMMAND = 3

    # A message action. The user selects the command from the message context
    # menu in Chat.
    MESSAGE_ACTION = 4
  end
end

#app_command_type ⇒ ::Google::Apps::Chat::V1::AppCommandMetadata::AppCommandType

Returns The type of Chat app command.

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'proto_docs/google/chat/v1/app_command_metadata.rb', line 32

class AppCommandMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of Chat app command. For details, see [Types of Chat
  # app commands](https://developers.google.com/workspace/chat/commands#types).
  module AppCommandType
    # Default value. Unspecified.
    APP_COMMAND_TYPE_UNSPECIFIED = 0

    # A slash command. The user sends the command in a Chat message.
    SLASH_COMMAND = 1

    # A quick command. The user selects the command from the Chat menu
    # in the message reply area.
    QUICK_COMMAND = 3

    # A message action. The user selects the command from the message context
    # menu in Chat.
    MESSAGE_ACTION = 4
  end
end