Class: Google::Apps::Chat::V1::Availability

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/availability.rb

Overview

Represents a user's current availability information in Google Chat, including their state (for example, Active, Away, Do Not Disturb) and any custom status.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#custom_status::Google::Apps::Chat::V1::CustomStatus

Returns Optional. The user's custom status.

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/chat/v1/availability.rb', line 47

class Availability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current availability state of the user.
  module State
    # Default value. The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The user is currently active, based on recent activity.
    ACTIVE = 1

    # The user is currently idle. This state indicates a period of inactivity
    # after being ACTIVE, before potentially transitioning to AWAY.
    IDLE = 2

    # The user is currently away. This can be either automatically set after
    # a period of inactivity in ACTIVE or IDLE state, or it can be manually set
    # by the user. When manually set via `MarkAsAway`, this state persists
    # regardless of user activity.
    AWAY = 3

    # The user is in Do Not Disturb state, which is manually set.
    DO_NOT_DISTURB = 4
  end
end

#do_not_disturb_metadata::Google::Apps::Chat::V1::DoNotDisturbMetadata (readonly)

Returns Output only. Metadata if the user state is set to DO_NOT_DISTURB.

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/chat/v1/availability.rb', line 47

class Availability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current availability state of the user.
  module State
    # Default value. The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The user is currently active, based on recent activity.
    ACTIVE = 1

    # The user is currently idle. This state indicates a period of inactivity
    # after being ACTIVE, before potentially transitioning to AWAY.
    IDLE = 2

    # The user is currently away. This can be either automatically set after
    # a period of inactivity in ACTIVE or IDLE state, or it can be manually set
    # by the user. When manually set via `MarkAsAway`, this state persists
    # regardless of user activity.
    AWAY = 3

    # The user is in Do Not Disturb state, which is manually set.
    DO_NOT_DISTURB = 4
  end
end

#name::String

Returns Identifier. Resource name of the user's availability.

Format: users/{user}/availability

{user} is the id for the Person in the People API or Admin SDK directory API. For example, users/123456789.

The user's email address or me can also be used as an alias to refer to the caller. For example, users/user@example.com or users/me.

Returns:

  • (::String)

    Identifier. Resource name of the user's availability.

    Format: users/{user}/availability

    {user} is the id for the Person in the People API or Admin SDK directory API. For example, users/123456789.

    The user's email address or me can also be used as an alias to refer to the caller. For example, users/user@example.com or users/me.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/chat/v1/availability.rb', line 47

class Availability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current availability state of the user.
  module State
    # Default value. The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The user is currently active, based on recent activity.
    ACTIVE = 1

    # The user is currently idle. This state indicates a period of inactivity
    # after being ACTIVE, before potentially transitioning to AWAY.
    IDLE = 2

    # The user is currently away. This can be either automatically set after
    # a period of inactivity in ACTIVE or IDLE state, or it can be manually set
    # by the user. When manually set via `MarkAsAway`, this state persists
    # regardless of user activity.
    AWAY = 3

    # The user is in Do Not Disturb state, which is manually set.
    DO_NOT_DISTURB = 4
  end
end

#state::Google::Apps::Chat::V1::Availability::State (readonly)

Returns Output only. The user's current availability state.

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/chat/v1/availability.rb', line 47

class Availability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current availability state of the user.
  module State
    # Default value. The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The user is currently active, based on recent activity.
    ACTIVE = 1

    # The user is currently idle. This state indicates a period of inactivity
    # after being ACTIVE, before potentially transitioning to AWAY.
    IDLE = 2

    # The user is currently away. This can be either automatically set after
    # a period of inactivity in ACTIVE or IDLE state, or it can be manually set
    # by the user. When manually set via `MarkAsAway`, this state persists
    # regardless of user activity.
    AWAY = 3

    # The user is in Do Not Disturb state, which is manually set.
    DO_NOT_DISTURB = 4
  end
end