Class: Google::Apps::Chat::V1::CreateSectionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/section.rb

Overview

Request message for creating a section.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource name where the section is created.

Format: users/{user}.

Returns:

  • (::String)

    Required. The parent resource name where the section is created.

    Format: users/{user}



117
118
119
120
# File 'proto_docs/google/chat/v1/section.rb', line 117

class CreateSectionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#section::Google::Apps::Chat::V1::Section

Returns Required. The section to create.

Returns:



117
118
119
120
# File 'proto_docs/google/chat/v1/section.rb', line 117

class CreateSectionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end