Class: Google::Apps::Chat::V1::CreateSpaceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/space.rb

Overview

A request to create a named space with no members.

Instance Attribute Summary collapse

Instance Attribute Details

#request_id ⇒ ::String

Optional. A unique ID for this request. A random UUID is recommended. Specifying a request ID makes the request idempotent, which ensures that multiple identical requests with the same request ID result in only a single space being created. Subsequent requests with the same request ID return the existing space and do not update the space, even if the requested details differ from the current state.

To use this field effectively:

  • Ensure that subsequent requests are identical and use the same authentication credentials as the original request.
  • If a space was already created with the provided request ID, the request returns that space. Note that the returned space might not be fully populated; the API echoes the space in your request with the system-assigned resource name populated. To retrieve the latest metadata for the space, call GetSpace.
  • Reusing an existing request ID with a different authenticated user results in an error.

Returns:

  • (::String) —

    Optional. A unique ID for this request. A random UUID is recommended. Specifying a request ID makes the request idempotent, which ensures that multiple identical requests with the same request ID result in only a single space being created. Subsequent requests with the same request ID return the existing space and do not update the space, even if the requested details differ from the current state.

    To use this field effectively:

    • Ensure that subsequent requests are identical and use the same authentication credentials as the original request.
    • If a space was already created with the provided request ID, the request returns that space. Note that the returned space might not be fully populated; the API echoes the space in your request with the system-assigned resource name populated. To retrieve the latest metadata for the space, call GetSpace.
    • Reusing an existing request ID with a different authenticated user results in an error.


509
510
511
512
# File 'proto_docs/google/chat/v1/space.rb', line 509

class CreateSpaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#space ⇒ ::Google::Apps::Chat::V1::Space

Returns Required. The displayName and spaceType fields must be populated. Only SpaceType.SPACE and SpaceType.GROUP_CHAT are supported. SpaceType.GROUP_CHAT can only be used if importMode is set to true.

If you receive the error message ALREADY_EXISTS, try a different displayName. An existing space within the Google Workspace organization might already use this display name.

The space name is assigned on the server so anything specified in this field will be ignored.

Returns:

  • (::Google::Apps::Chat::V1::Space) —

    Required. The displayName and spaceType fields must be populated. Only SpaceType.SPACE and SpaceType.GROUP_CHAT are supported. SpaceType.GROUP_CHAT can only be used if importMode is set to true.

    If you receive the error message ALREADY_EXISTS, try a different displayName. An existing space within the Google Workspace organization might already use this display name.

    The space name is assigned on the server so anything specified in this field will be ignored.



509
510
511
512
# File 'proto_docs/google/chat/v1/space.rb', line 509

class CreateSpaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end