Class: Google::Apps::Chat::V1::DoNotDisturbMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/availability.rb

Overview

Metadata associated with the DO_NOT_DISTURB availability state, specifying when the state is set to expire.

Instance Attribute Summary collapse

Instance Attribute Details

#expiration_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp until which the user should be marked as DO_NOT_DISTURB. This can be maximum of 1 year in the future.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Timestamp until which the user should be marked as DO_NOT_DISTURB. This can be maximum of 1 year in the future.



107
108
109
110
# File 'proto_docs/google/chat/v1/availability.rb', line 107

class DoNotDisturbMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end