Class: Google::Apps::Chat::V1::ForwardedMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/message.rb

Overview

Metadata about the source space from which a message was forwarded.

Instance Attribute Summary collapse

Instance Attribute Details

#space::String (readonly)

Returns Output only. The resource name of the source space. Format: spaces/{space}.

Returns:

  • (::String)

    Output only. The resource name of the source space. Format: spaces/{space}



347
348
349
350
# File 'proto_docs/google/chat/v1/message.rb', line 347

class ForwardedMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#space_display_name::String (readonly)

Returns Output only. The display name of the source space or DM at the time of forwarding. For SPACE, this is the space name. For DIRECT_MESSAGE, this is the other participant's name (e.g., "User A"). For GROUP_CHAT, this is a generated name based on members' first names, limited to 5 including the creator (e.g., "User A, User B").

Returns:

  • (::String)

    Output only. The display name of the source space or DM at the time of forwarding. For SPACE, this is the space name. For DIRECT_MESSAGE, this is the other participant's name (e.g., "User A"). For GROUP_CHAT, this is a generated name based on members' first names, limited to 5 including the creator (e.g., "User A, User B").



347
348
349
350
# File 'proto_docs/google/chat/v1/message.rb', line 347

class ForwardedMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end