Class: Google::Apps::Chat::V1::ListMessagePinsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/message_pin.rb

Overview

Request message for listing message pins.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size ⇒ ::Integer

Optional. The maximum number of message pins returned. The service might return fewer messages than this value. The maximum value is 100. If you use a value more than 100, it's automatically changed to 100. If unspecified, at most 100 message pins will be returned. Negative values return an INVALID_ARGUMENT error.

Returns:

  • (::Integer) —

    Optional. The maximum number of message pins returned. The service might return fewer messages than this value. The maximum value is 100. If you use a value more than 100, it's automatically changed to 100. If unspecified, at most 100 message pins will be returned. Negative values return an INVALID_ARGUMENT error.



63
64
65
66
# File 'proto_docs/google/chat/v1/message_pin.rb', line 63

class ListMessagePinsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token ⇒ ::String

Returns Optional. A page token received from a previous list message pins call. Provide this parameter to retrieve the subsequent page.

When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.

Returns:

  • (::String) —

    Optional. A page token received from a previous list message pins call. Provide this parameter to retrieve the subsequent page.

    When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.



63
64
65
66
# File 'proto_docs/google/chat/v1/message_pin.rb', line 63

class ListMessagePinsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent ⇒ ::String

Returns Required. The parent space which owns the collection of pinned items Format: spaces/{space}.

Returns:

  • (::String) —

    Required. The parent space which owns the collection of pinned items Format: spaces/{space}



63
64
65
66
# File 'proto_docs/google/chat/v1/message_pin.rb', line 63

class ListMessagePinsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end