Class: Google::Apps::Chat::V1::ListSectionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/section.rb

Overview

Request message for listing sections.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of sections to return. The service may return fewer than this value.

If unspecified, at most 10 sections will be returned.

The maximum value is 100. If you use a value more than 100, it's automatically changed to 100.

Negative values return an INVALID_ARGUMENT error.

Returns:

  • (::Integer)

    Optional. The maximum number of sections to return. The service may return fewer than this value.

    If unspecified, at most 10 sections will be returned.

    The maximum value is 100. If you use a value more than 100, it's automatically changed to 100.

    Negative values return an INVALID_ARGUMENT error.



183
184
185
186
# File 'proto_docs/google/chat/v1/section.rb', line 183

class ListSectionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous list sections call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.

Returns:

  • (::String)

    Optional. A page token, received from a previous list sections call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.



183
184
185
186
# File 'proto_docs/google/chat/v1/section.rb', line 183

class ListSectionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which is the user resource name that owns this collection of sections. Only supports listing sections for the calling user. To refer to the calling user, set one of the following:

  • The me alias. For example, users/me.

  • Their Workspace email address. For example, users/user@example.com.

  • Their user id. For example, users/123456789.

Format: users/{user}.

Returns:

  • (::String)

    Required. The parent, which is the user resource name that owns this collection of sections. Only supports listing sections for the calling user. To refer to the calling user, set one of the following:

    • The me alias. For example, users/me.

    • Their Workspace email address. For example, users/user@example.com.

    • Their user id. For example, users/123456789.

    Format: users/{user}



183
184
185
186
# File 'proto_docs/google/chat/v1/section.rb', line 183

class ListSectionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end