Class: Google::Apps::Chat::V1::ListSectionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/section.rb

Overview

Response message for listing sections.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



196
197
198
199
# File 'proto_docs/google/chat/v1/section.rb', line 196

class ListSectionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sections::Array<::Google::Apps::Chat::V1::Section>

Returns The sections from the specified user.

Returns:



196
197
198
199
# File 'proto_docs/google/chat/v1/section.rb', line 196

class ListSectionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end