Class: Google::Apps::Chat::V1::MoveSectionItemRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/section.rb

Overview

Request message for moving a section item across sections.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the section item to move.

Format: users/{user}/sections/{section}/items/{item}.

Returns:

  • (::String)

    Required. The resource name of the section item to move.

    Format: users/{user}/sections/{section}/items/{item}



316
317
318
319
# File 'proto_docs/google/chat/v1/section.rb', line 316

class MoveSectionItemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_section::String

Returns Required. The resource name of the section to move the section item to.

Format: users/{user}/sections/{section}.

Returns:

  • (::String)

    Required. The resource name of the section to move the section item to.

    Format: users/{user}/sections/{section}



316
317
318
319
# File 'proto_docs/google/chat/v1/section.rb', line 316

class MoveSectionItemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end