Class: Google::Apps::Chat::V1::QuotedMessageSnapshot
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::QuotedMessageSnapshot
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
Provides a snapshot of the content of the quoted message at the time of quoting or forwarding
Instance Attribute Summary collapse
-
#annotations ⇒ ::Array<::Google::Apps::Chat::V1::Annotation>
readonly
Output only.
-
#attachments ⇒ ::Array<::Google::Apps::Chat::V1::Attachment>
readonly
Output only.
-
#formatted_text ⇒ ::String
readonly
Output only.
-
#sender ⇒ ::String
readonly
Output only.
-
#text ⇒ ::String
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Array<::Google::Apps::Chat::V1::Annotation> (readonly)
Returns Output only. Annotations parsed from the text body of the quoted message. Populated only for FORWARD quote type.
340 341 342 343 |
# File 'proto_docs/google/chat/v1/message.rb', line 340 class QuotedMessageSnapshot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#attachments ⇒ ::Array<::Google::Apps::Chat::V1::Attachment> (readonly)
Returns Output only. Attachments that were part of the quoted message. These are copies of the quoted message's attachment metadata. Populated only for FORWARD quote type.
340 341 342 343 |
# File 'proto_docs/google/chat/v1/message.rb', line 340 class QuotedMessageSnapshot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#formatted_text ⇒ ::String (readonly)
Returns Output only. Contains the quoted message text with markups added to
support rich formatting like hyperlinks,custom emojis, markup, etc.
Populated only for FORWARD quote type.
340 341 342 343 |
# File 'proto_docs/google/chat/v1/message.rb', line 340 class QuotedMessageSnapshot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sender ⇒ ::String (readonly)
Returns Output only. The quoted message's author name. Populated for both REPLY & FORWARD quote types.
340 341 342 343 |
# File 'proto_docs/google/chat/v1/message.rb', line 340 class QuotedMessageSnapshot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::String (readonly)
Returns Output only. Snapshot of the quoted message's text content.
340 341 342 343 |
# File 'proto_docs/google/chat/v1/message.rb', line 340 class QuotedMessageSnapshot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |