Class: Google::Apps::Chat::V1::SearchMessageResult
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::SearchMessageResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
A single result item from a message search.
Instance Attribute Summary collapse
-
#message ⇒ ::Google::Apps::Chat::V1::Message
The matched message.
-
#read ⇒ ::Boolean
Indicates if the matched message is read by the calling user.
-
#space_mute_setting ⇒ ::Google::Apps::Chat::V1::SpaceNotificationSetting::MuteSetting
The mute setting of the calling user for the space where the message is posted.
Instance Attribute Details
#message ⇒ ::Google::Apps::Chat::V1::Message
Returns The matched message.
1085 1086 1087 1088 |
# File 'proto_docs/google/chat/v1/message.rb', line 1085 class SearchMessageResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read ⇒ ::Boolean
Returns Indicates if the matched message is read by the calling user.
Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the
calling credentials include one of the following authorization
scopes:
- `https://www.googleapis.com/auth/chat.users.readstate.readonly`
- `https://www.googleapis.com/auth/chat.users.readstate`.
1085 1086 1087 1088 |
# File 'proto_docs/google/chat/v1/message.rb', line 1085 class SearchMessageResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#space_mute_setting ⇒ ::Google::Apps::Chat::V1::SpaceNotificationSetting::MuteSetting
Returns The mute setting of the calling user for the space where the message is posted. The caller app can use this information to decide how to process the message depending on whether the space is muted for the user or not.
Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the
calling credentials include the following authorization
scope:
- `https://www.googleapis.com/auth/chat.users.spacesettings`.
1085 1086 1087 1088 |
# File 'proto_docs/google/chat/v1/message.rb', line 1085 class SearchMessageResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |