Module: Google::Apps::Chat::V1::SearchMessagesRequest::SearchMessagesView

Defined in:
proto_docs/google/chat/v1/message.rb

Overview

The kinds of view that are supported for partial search results.

Constant Summary collapse

SEARCH_MESSAGES_VIEW_UNSPECIFIED =

The default / unset value. The API will default to the BASIC view.

0
SEARCH_MESSAGES_VIEW_BASIC =

Includes only the matched messages in the results, but no additional metadata. This is the default value.

1
SEARCH_MESSAGES_VIEW_FULL =

Includes everything in the results: the matched messages and additional metadata.

2