Class: Google::Apps::Chat::V1::SearchMessagesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/message.rb

Overview

Response message for searching messages.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages.



1005
1006
1007
1008
# File 'proto_docs/google/chat/v1/message.rb', line 1005

class SearchMessagesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#results::Array<::Google::Apps::Chat::V1::SearchMessageResult>

Returns The list of search results that matched the query.

Returns:



1005
1006
1007
1008
# File 'proto_docs/google/chat/v1/message.rb', line 1005

class SearchMessagesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end