Class: Google::Apps::Chat::V1::SearchSpacesRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::SearchSpacesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
Request to search for a list of spaces based on a query.
Instance Attribute Summary collapse
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
The maximum number of spaces to return.
-
#page_token ⇒ ::String
A token, received from the previous search spaces call.
-
#query ⇒ ::String
Required.
-
#use_admin_access ⇒ ::Boolean
When
true, the method runs using the user's Google Workspace administrator privileges.
Instance Attribute Details
#order_by ⇒ ::String
959 960 961 962 |
# File 'proto_docs/google/chat/v1/space.rb', line 959 class SearchSpacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
959 960 961 962 |
# File 'proto_docs/google/chat/v1/space.rb', line 959 class SearchSpacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
959 960 961 962 |
# File 'proto_docs/google/chat/v1/space.rb', line 959 class SearchSpacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::String
959 960 961 962 |
# File 'proto_docs/google/chat/v1/space.rb', line 959 class SearchSpacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_admin_access ⇒ ::Boolean
959 960 961 962 |
# File 'proto_docs/google/chat/v1/space.rb', line 959 class SearchSpacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |