Class: Google::Apps::Chat::V1::Section

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/chat/v1/section.rb

Overview

Represents a section in Google Chat. Sections help users organize their spaces. There are two types of sections:

  1. System Sections: These are predefined sections managed by Google Chat. Their resource names are fixed, and they cannot be created, deleted, or have their display_name modified. Examples include:

    • users/{user}/sections/default-direct-messages
    • users/{user}/sections/default-spaces
    • users/{user}/sections/default-apps
  2. Custom Sections: These are sections created and managed by the user. Creating a custom section using CreateSection requires a display_name. Custom sections can be updated using UpdateSection and deleted using DeleteSection.

Defined Under Namespace

Modules: SectionType

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Optional. The section's display name. Only populated for sections of type CUSTOM_SECTION. Supports up to 80 characters. Required when creating a CUSTOM_SECTION.

Returns:

  • (::String)

    Optional. The section's display name. Only populated for sections of type CUSTOM_SECTION. Supports up to 80 characters. Required when creating a CUSTOM_SECTION.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/chat/v1/section.rb', line 64

class Section
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Section types.
  module SectionType
    # Unspecified section type.
    SECTION_TYPE_UNSPECIFIED = 0

    # Custom section.
    CUSTOM_SECTION = 1

    # Default section containing
    # [DIRECT_MESSAGE](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # between two human users or
    # [GROUP_CHAT](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # spaces that don't belong to any custom section.
    DEFAULT_DIRECT_MESSAGES = 2

    # Default spaces that don't belong to any custom section.
    DEFAULT_SPACES = 3

    # Default section containing a user's installed apps.
    DEFAULT_APPS = 6
  end
end

#name::String

Returns Identifier. Resource name of the section.

For system sections, the section ID is a constant string:

  • DEFAULT_DIRECT_MESSAGES: users/{user}/sections/default-direct-messages
  • DEFAULT_SPACES: users/{user}/sections/default-spaces
  • DEFAULT_APPS: users/{user}/sections/default-apps

Format: users/{user}/sections/{section}.

Returns:

  • (::String)

    Identifier. Resource name of the section.

    For system sections, the section ID is a constant string:

    • DEFAULT_DIRECT_MESSAGES: users/{user}/sections/default-direct-messages
    • DEFAULT_SPACES: users/{user}/sections/default-spaces
    • DEFAULT_APPS: users/{user}/sections/default-apps

    Format: users/{user}/sections/{section}



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/chat/v1/section.rb', line 64

class Section
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Section types.
  module SectionType
    # Unspecified section type.
    SECTION_TYPE_UNSPECIFIED = 0

    # Custom section.
    CUSTOM_SECTION = 1

    # Default section containing
    # [DIRECT_MESSAGE](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # between two human users or
    # [GROUP_CHAT](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # spaces that don't belong to any custom section.
    DEFAULT_DIRECT_MESSAGES = 2

    # Default spaces that don't belong to any custom section.
    DEFAULT_SPACES = 3

    # Default section containing a user's installed apps.
    DEFAULT_APPS = 6
  end
end

#sort_order::Integer

Returns Output only. The order of the section in relation to other sections. Sections with a lower sort_order value appear before sections with a higher value.

Returns:

  • (::Integer)

    Output only. The order of the section in relation to other sections. Sections with a lower sort_order value appear before sections with a higher value.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/chat/v1/section.rb', line 64

class Section
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Section types.
  module SectionType
    # Unspecified section type.
    SECTION_TYPE_UNSPECIFIED = 0

    # Custom section.
    CUSTOM_SECTION = 1

    # Default section containing
    # [DIRECT_MESSAGE](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # between two human users or
    # [GROUP_CHAT](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # spaces that don't belong to any custom section.
    DEFAULT_DIRECT_MESSAGES = 2

    # Default spaces that don't belong to any custom section.
    DEFAULT_SPACES = 3

    # Default section containing a user's installed apps.
    DEFAULT_APPS = 6
  end
end

#type::Google::Apps::Chat::V1::Section::SectionType

Returns Required. The type of the section.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/chat/v1/section.rb', line 64

class Section
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Section types.
  module SectionType
    # Unspecified section type.
    SECTION_TYPE_UNSPECIFIED = 0

    # Custom section.
    CUSTOM_SECTION = 1

    # Default section containing
    # [DIRECT_MESSAGE](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # between two human users or
    # [GROUP_CHAT](https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#spacetype)
    # spaces that don't belong to any custom section.
    DEFAULT_DIRECT_MESSAGES = 2

    # Default spaces that don't belong to any custom section.
    DEFAULT_SPACES = 3

    # Default section containing a user's installed apps.
    DEFAULT_APPS = 6
  end
end