Module: Google::Apps::Chat::V1::Space::SpaceThreadingState
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
Specifies the type of threading state in the Chat space.
Constant Summary collapse
- SPACE_THREADING_STATE_UNSPECIFIED =
Reserved.
0- THREADED_MESSAGES =
Spaces that support message threads. When users respond to a message, they can reply in-thread, which keeps their response in the context of the original message.
2- GROUPED_MESSAGES =
Named spaces where the conversation is organized by topic. Topics and their replies are grouped together.
3- UNTHREADED_MESSAGES =
Spaces that don't support message threading. This space threading state is only used for special cases including:
- Continuous meeting chat where threading is intentionally turned off.
- Legacy group conversations that were created prior to 2022.
4