Module: Google::Apps::Chat::V1::SpaceView

Defined in:
proto_docs/google/chat/v1/space.rb

Overview

A view that specifies which fields should be populated on the Space resource. To ensure compatibility with future releases, we recommend that your code account for additional values.

Constant Summary collapse

SPACE_VIEW_UNSPECIFIED =

The default / unset value.

0
SPACE_VIEW_RESOURCE_NAME_ONLY =

Populates only the Space resource name.

3
SPACE_VIEW_EXPANDED =

Populates Space resource fields. Note: the permissionSettings field will not be populated. Requests that specify SPACE_VIEW_EXPANDED must include scopes that allow reading space data, for example, https://www.googleapis.com/auth/chat.spaces or https://www.googleapis.com/auth/chat.spaces.readonly.

4