Class: Google::Apps::Card::V1::BorderStyle
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::BorderStyle
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
The style options for the border of a card or widget, including the border type and color.
Defined Under Namespace
Modules: BorderType
Instance Attribute Summary collapse
-
#corner_radius ⇒ ::Integer
The corner radius for the border.
-
#stroke_color ⇒ ::Google::Type::Color
The colors to use when the type is
BORDER_TYPE_STROKE. -
#type ⇒ ::Google::Apps::Card::V1::BorderStyle::BorderType
The border type.
Instance Attribute Details
#corner_radius ⇒ ::Integer
Returns The corner radius for the border.
1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1864 class BorderStyle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the border types applied to widgets. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module BorderType # Don't use. Unspecified. BORDER_TYPE_UNSPECIFIED = 0 # No border. NO_BORDER = 1 # Default value. Outline. STROKE = 2 end end |
#stroke_color ⇒ ::Google::Type::Color
Returns The colors to use when the type is BORDER_TYPE_STROKE.
To set the stroke color, specify a value for the red, green, and blue
fields.
The value must be a float number between 0 and 1 based on the RGB color
value, where 0 (0/255) represents the absence of color and 1 (255/255)
represents the maximum intensity of the color.
For example, the following sets the color to red at its maximum intensity:
"color": {
"red": 1,
"green": 0,
"blue": 0,
}
The alpha field is unavailable for stroke color. If specified, this field
is ignored.
1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1864 class BorderStyle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the border types applied to widgets. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module BorderType # Don't use. Unspecified. BORDER_TYPE_UNSPECIFIED = 0 # No border. NO_BORDER = 1 # Default value. Outline. STROKE = 2 end end |
#type ⇒ ::Google::Apps::Card::V1::BorderStyle::BorderType
Returns The border type.
1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1864 class BorderStyle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the border types applied to widgets. # # [Google Workspace add-ons # and Chat apps](https://developers.google.com/workspace/extend): module BorderType # Don't use. Unspecified. BORDER_TYPE_UNSPECIFIED = 0 # No border. NO_BORDER = 1 # Default value. Outline. STROKE = 2 end end |