Module: Google::Apps::Card::V1::Card::DividerStyle
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
The divider style of a card. Currently only used for dividers betweens card sections.
Constant Summary collapse
- DIVIDER_STYLE_UNSPECIFIED =
Don't use. Unspecified.
0- SOLID_DIVIDER =
Default option. Render a solid divider.
1- NO_DIVIDER =
If set, no divider is rendered. This style completely removes the divider from the layout. The result is equivalent to not adding a divider at all.
2