Class: Google::Apps::Card::V1::ChipList
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::ChipList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
A list of chips layed out horizontally, which can either scroll horizontally or wrap to the next line.
Defined Under Namespace
Modules: Layout
Instance Attribute Summary collapse
-
#chips ⇒ ::Array<::Google::Apps::Card::V1::Chip>
An array of chips.
-
#layout ⇒ ::Google::Apps::Card::V1::ChipList::Layout
Specified chip list layout.
Instance Attribute Details
#chips ⇒ ::Array<::Google::Apps::Card::V1::Chip>
Returns An array of chips.
2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 2569 class ChipList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The chip list layout. module Layout # Don't use. Unspecified. LAYOUT_UNSPECIFIED = 0 # Default value. The chip list wraps to the next line if there isn't enough # horizontal space. WRAPPED = 1 # The chips scroll horizontally if they don't fit in the available space. HORIZONTAL_SCROLLABLE = 2 end end |
#layout ⇒ ::Google::Apps::Card::V1::ChipList::Layout
Returns Specified chip list layout.
2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 2569 class ChipList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The chip list layout. module Layout # Don't use. Unspecified. LAYOUT_UNSPECIFIED = 0 # Default value. The chip list wraps to the next line if there isn't enough # horizontal space. WRAPPED = 1 # The chips scroll horizontally if they don't fit in the available space. HORIZONTAL_SCROLLABLE = 2 end end |