Class: Google::Apps::Card::V1::Grid::GridItem
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::Grid::GridItem
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
Represents an item in a grid layout. Items can contain text, an image, or both text and an image.
Defined Under Namespace
Modules: GridItemLayout
Instance Attribute Summary collapse
-
#id ⇒ ::String
A user-specified identifier for this grid item.
-
#image ⇒ ::Google::Apps::Card::V1::ImageComponent
The image that displays in the grid item.
-
#layout ⇒ ::Google::Apps::Card::V1::Grid::GridItem::GridItemLayout
The layout to use for the grid item.
-
#subtitle ⇒ ::String
The grid item's subtitle.
-
#title ⇒ ::String
The grid item's title.
Instance Attribute Details
#id ⇒ ::String
A user-specified identifier for this grid item. This identifier is
returned in the parent grid's onClick callback parameters.
1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1996 class GridItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various layout options available for a grid item. # # [Google Workspace add-ons and Chat # apps](https://developers.google.com/workspace/extend): module GridItemLayout # Don't use. Unspecified. GRID_ITEM_LAYOUT_UNSPECIFIED = 0 # The title and subtitle are shown below the grid item's image. TEXT_BELOW = 1 # The title and subtitle are shown above the grid item's image. TEXT_ABOVE = 2 end end |
#image ⇒ ::Google::Apps::Card::V1::ImageComponent
Returns The image that displays in the grid item.
1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1996 class GridItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various layout options available for a grid item. # # [Google Workspace add-ons and Chat # apps](https://developers.google.com/workspace/extend): module GridItemLayout # Don't use. Unspecified. GRID_ITEM_LAYOUT_UNSPECIFIED = 0 # The title and subtitle are shown below the grid item's image. TEXT_BELOW = 1 # The title and subtitle are shown above the grid item's image. TEXT_ABOVE = 2 end end |
#layout ⇒ ::Google::Apps::Card::V1::Grid::GridItem::GridItemLayout
Returns The layout to use for the grid item.
1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1996 class GridItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various layout options available for a grid item. # # [Google Workspace add-ons and Chat # apps](https://developers.google.com/workspace/extend): module GridItemLayout # Don't use. Unspecified. GRID_ITEM_LAYOUT_UNSPECIFIED = 0 # The title and subtitle are shown below the grid item's image. TEXT_BELOW = 1 # The title and subtitle are shown above the grid item's image. TEXT_ABOVE = 2 end end |
#subtitle ⇒ ::String
Returns The grid item's subtitle.
1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1996 class GridItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various layout options available for a grid item. # # [Google Workspace add-ons and Chat # apps](https://developers.google.com/workspace/extend): module GridItemLayout # Don't use. Unspecified. GRID_ITEM_LAYOUT_UNSPECIFIED = 0 # The title and subtitle are shown below the grid item's image. TEXT_BELOW = 1 # The title and subtitle are shown above the grid item's image. TEXT_ABOVE = 2 end end |
#title ⇒ ::String
Returns The grid item's title.
1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 1996 class GridItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various layout options available for a grid item. # # [Google Workspace add-ons and Chat # apps](https://developers.google.com/workspace/extend): module GridItemLayout # Don't use. Unspecified. GRID_ITEM_LAYOUT_UNSPECIFIED = 0 # The title and subtitle are shown below the grid item's image. TEXT_BELOW = 1 # The title and subtitle are shown above the grid item's image. TEXT_ABOVE = 2 end end |