Class: Google::Apps::Card::V1::Validation
- Inherits:
-
Object
- Object
- Google::Apps::Card::V1::Validation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/card/v1/card.rb
Overview
Represents the necessary data for validating the widget it's attached to.
Defined Under Namespace
Modules: InputType
Instance Attribute Summary collapse
-
#character_limit ⇒ ::Integer
Specify the character limit for text input widgets.
-
#input_type ⇒ ::Google::Apps::Card::V1::Validation::InputType
Specify the type of the input widgets.
Instance Attribute Details
#character_limit ⇒ ::Integer
Returns Specify the character limit for text input widgets. Note that this is only used for text input and is ignored for other widgets.
2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 2532 class Validation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the input widget. module InputType # Unspecified type. Do not use. INPUT_TYPE_UNSPECIFIED = 0 # Regular text that accepts all characters. TEXT = 1 # An integer value. INTEGER = 2 # A float value. FLOAT = 3 # An email address. EMAIL = 4 # A emoji selected from system-provided emoji picker. EMOJI_PICKER = 5 end end |
#input_type ⇒ ::Google::Apps::Card::V1::Validation::InputType
Returns Specify the type of the input widgets.
2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 |
# File 'proto_docs/google/apps/card/v1/card.rb', line 2532 class Validation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the input widget. module InputType # Unspecified type. Do not use. INPUT_TYPE_UNSPECIFIED = 0 # Regular text that accepts all characters. TEXT = 1 # An integer value. INTEGER = 2 # A float value. FLOAT = 3 # An email address. EMAIL = 4 # A emoji selected from system-provided emoji picker. EMOJI_PICKER = 5 end end |