Class: Google::Apps::Chat::V1::ActionResponse
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::ActionResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
Parameters that a Chat app can use to configure how its response is posted.
Defined Under Namespace
Modules: ResponseType Classes: SelectionItems, UpdatedWidget
Instance Attribute Summary collapse
-
#dialog_action ⇒ ::Google::Apps::Chat::V1::DialogAction
Input only.
-
#type ⇒ ::Google::Apps::Chat::V1::ActionResponse::ResponseType
Input only.
-
#updated_widget ⇒ ::Google::Apps::Chat::V1::ActionResponse::UpdatedWidget
Input only.
-
#url ⇒ ::String
Input only.
Instance Attribute Details
#dialog_action ⇒ ::Google::Apps::Chat::V1::DialogAction
Returns Input only. A response to an interaction event related to a
dialog. Must be
accompanied by ResponseType.Dialog.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'proto_docs/google/chat/v1/message.rb', line 395 class ActionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of widget autocomplete results. # @!attribute [rw] items # @return [::Array<::Google::Apps::Card::V1::SelectionInput::SelectionItem>] # An array of the SelectionItem objects. class SelectionItems include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # For `selectionInput` widgets, returns autocomplete suggestions for a # multiselect menu. # @!attribute [rw] suggestions # @return [::Google::Apps::Chat::V1::ActionResponse::SelectionItems] # List of widget autocomplete results # @!attribute [rw] widget # @return [::String] # The ID of the updated widget. The ID must match the one for the # widget that triggered the update request. class UpdatedWidget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of Chat app response. module ResponseType # Default type that's handled as `NEW_MESSAGE`. TYPE_UNSPECIFIED = 0 # Post as a new message in the topic. NEW_MESSAGE = 1 # Update the Chat app's message. This is only permitted on a `CARD_CLICKED` # event where the message sender type is `BOT`. UPDATE_MESSAGE = 2 # Update the cards on a user's message. This is only permitted as a # response to a `MESSAGE` event with a matched url, or a `CARD_CLICKED` # event where the message sender type is `HUMAN`. Text is ignored. UPDATE_USER_MESSAGE_CARDS = 6 # Privately ask the user for additional authentication or configuration. REQUEST_CONFIG = 3 # Presents a # [dialog](https://developers.google.com/workspace/chat/dialogs). DIALOG = 4 # Widget text autocomplete options query. UPDATE_WIDGET = 7 end end |
#type ⇒ ::Google::Apps::Chat::V1::ActionResponse::ResponseType
Returns Input only. The type of Chat app response.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'proto_docs/google/chat/v1/message.rb', line 395 class ActionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of widget autocomplete results. # @!attribute [rw] items # @return [::Array<::Google::Apps::Card::V1::SelectionInput::SelectionItem>] # An array of the SelectionItem objects. class SelectionItems include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # For `selectionInput` widgets, returns autocomplete suggestions for a # multiselect menu. # @!attribute [rw] suggestions # @return [::Google::Apps::Chat::V1::ActionResponse::SelectionItems] # List of widget autocomplete results # @!attribute [rw] widget # @return [::String] # The ID of the updated widget. The ID must match the one for the # widget that triggered the update request. class UpdatedWidget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of Chat app response. module ResponseType # Default type that's handled as `NEW_MESSAGE`. TYPE_UNSPECIFIED = 0 # Post as a new message in the topic. NEW_MESSAGE = 1 # Update the Chat app's message. This is only permitted on a `CARD_CLICKED` # event where the message sender type is `BOT`. UPDATE_MESSAGE = 2 # Update the cards on a user's message. This is only permitted as a # response to a `MESSAGE` event with a matched url, or a `CARD_CLICKED` # event where the message sender type is `HUMAN`. Text is ignored. UPDATE_USER_MESSAGE_CARDS = 6 # Privately ask the user for additional authentication or configuration. REQUEST_CONFIG = 3 # Presents a # [dialog](https://developers.google.com/workspace/chat/dialogs). DIALOG = 4 # Widget text autocomplete options query. UPDATE_WIDGET = 7 end end |
#updated_widget ⇒ ::Google::Apps::Chat::V1::ActionResponse::UpdatedWidget
Returns Input only. The response of the updated widget.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'proto_docs/google/chat/v1/message.rb', line 395 class ActionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of widget autocomplete results. # @!attribute [rw] items # @return [::Array<::Google::Apps::Card::V1::SelectionInput::SelectionItem>] # An array of the SelectionItem objects. class SelectionItems include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # For `selectionInput` widgets, returns autocomplete suggestions for a # multiselect menu. # @!attribute [rw] suggestions # @return [::Google::Apps::Chat::V1::ActionResponse::SelectionItems] # List of widget autocomplete results # @!attribute [rw] widget # @return [::String] # The ID of the updated widget. The ID must match the one for the # widget that triggered the update request. class UpdatedWidget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of Chat app response. module ResponseType # Default type that's handled as `NEW_MESSAGE`. TYPE_UNSPECIFIED = 0 # Post as a new message in the topic. NEW_MESSAGE = 1 # Update the Chat app's message. This is only permitted on a `CARD_CLICKED` # event where the message sender type is `BOT`. UPDATE_MESSAGE = 2 # Update the cards on a user's message. This is only permitted as a # response to a `MESSAGE` event with a matched url, or a `CARD_CLICKED` # event where the message sender type is `HUMAN`. Text is ignored. UPDATE_USER_MESSAGE_CARDS = 6 # Privately ask the user for additional authentication or configuration. REQUEST_CONFIG = 3 # Presents a # [dialog](https://developers.google.com/workspace/chat/dialogs). DIALOG = 4 # Widget text autocomplete options query. UPDATE_WIDGET = 7 end end |
#url ⇒ ::String
Returns Input only. URL for users to authenticate or configure. (Only for
REQUEST_CONFIG response types.).
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'proto_docs/google/chat/v1/message.rb', line 395 class ActionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of widget autocomplete results. # @!attribute [rw] items # @return [::Array<::Google::Apps::Card::V1::SelectionInput::SelectionItem>] # An array of the SelectionItem objects. class SelectionItems include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # For `selectionInput` widgets, returns autocomplete suggestions for a # multiselect menu. # @!attribute [rw] suggestions # @return [::Google::Apps::Chat::V1::ActionResponse::SelectionItems] # List of widget autocomplete results # @!attribute [rw] widget # @return [::String] # The ID of the updated widget. The ID must match the one for the # widget that triggered the update request. class UpdatedWidget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of Chat app response. module ResponseType # Default type that's handled as `NEW_MESSAGE`. TYPE_UNSPECIFIED = 0 # Post as a new message in the topic. NEW_MESSAGE = 1 # Update the Chat app's message. This is only permitted on a `CARD_CLICKED` # event where the message sender type is `BOT`. UPDATE_MESSAGE = 2 # Update the cards on a user's message. This is only permitted as a # response to a `MESSAGE` event with a matched url, or a `CARD_CLICKED` # event where the message sender type is `HUMAN`. Text is ignored. UPDATE_USER_MESSAGE_CARDS = 6 # Privately ask the user for additional authentication or configuration. REQUEST_CONFIG = 3 # Presents a # [dialog](https://developers.google.com/workspace/chat/dialogs). DIALOG = 4 # Widget text autocomplete options query. UPDATE_WIDGET = 7 end end |