Class: Google::Apps::Chat::V1::Audience
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::Audience
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/audience.rb
Overview
A target audience in Google Chat. A target audience represents a group of users within a Google Workspace organization, defined by an administrator. Target audiences are used to configure access and visibility settings for resources, such as making a space discoverable to a specific group of users.
For more details, see Target audiences and Make a space discoverable to a target audience.
Instance Attribute Summary collapse
-
#name ⇒ ::String
The resource name of the target audience who can discover or join the space.
Instance Attribute Details
#name ⇒ ::String
Returns The resource name of the target
audience who can discover
or join the space. For details, see Make a space
discoverable to a target
audience.
Format: audiences/{audience}
To use the default target audience for the Google Workspace organization,
set to audiences/default.
44 45 46 47 |
# File 'proto_docs/google/chat/v1/audience.rb', line 44 class Audience include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |