Module: Google::Apps::Chat::V1::Availability::State
- Defined in:
- proto_docs/google/chat/v1/availability.rb
Overview
Represents the current availability state of the user.
Constant Summary collapse
- STATE_UNSPECIFIED =
Default value. The state is unspecified.
0- ACTIVE =
The user is currently active, based on recent activity.
1- IDLE =
The user is currently idle. This state indicates a period of inactivity after being ACTIVE, before potentially transitioning to AWAY.
2- AWAY =
The user is currently away. This can be either automatically set after a period of inactivity in ACTIVE or IDLE state, or it can be manually set by the user. When manually set via
MarkAsAway, this state persists regardless of user activity. 3- DO_NOT_DISTURB =
The user is in Do Not Disturb state, which is manually set.
4