Class: Google::Apps::Chat::V1::CardWithId
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::CardWithId
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
A card in a Google Chat message.
Chat apps can create cards with app authentication. As part of the Developer Preview Program, if your Chat app authenticates as a user, it can create card messages. If your Chat app is not part of Developer Preview Program, it can't create cards with user authentication.
To learn how to create a message that contains cards, see Send a message.
Instance Attribute Summary collapse
-
#card ⇒ ::Google::Apps::Card::V1::Card
A card.
-
#card_id ⇒ ::String
Required if the message contains multiple cards.
Instance Attribute Details
#card ⇒ ::Google::Apps::Card::V1::Card
Returns A card. Maximum size is 32 KB.
840 841 842 843 |
# File 'proto_docs/google/chat/v1/message.rb', line 840 class CardWithId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#card_id ⇒ ::String
Returns Required if the message contains multiple cards. A unique identifier for a card in a message.
840 841 842 843 |
# File 'proto_docs/google/chat/v1/message.rb', line 840 class CardWithId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |