Class: Google::Apps::Chat::V1::CreateMessageNotificationOptions
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::CreateMessageNotificationOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
Options for the notification behavior when the message is posted.
Defined Under Namespace
Modules: NotificationType
Instance Attribute Summary collapse
-
#notification_type ⇒ ::Google::Apps::Chat::V1::CreateMessageNotificationOptions::NotificationType
The notification type for the message.
Instance Attribute Details
#notification_type ⇒ ::Google::Apps::Chat::V1::CreateMessageNotificationOptions::NotificationType
Returns The notification type for the message.
655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 |
# File 'proto_docs/google/chat/v1/message.rb', line 655 class CreateMessageNotificationOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The notification types options for the message. module NotificationType # Default behavior. Notification behavior is similar to when the human user # sends the message using the Chat UI: no notification is sent to the # human sender. NOTIFICATION_TYPE_NONE = 0 # Force notify recipients. This bypasses users' space notification settings # and [Chat Do Not Disturb # settings](https://support.google.com/chat/answer/9093489). This option # does not bypass device-level Do Not Disturb settings. # # Requires [app authentication] # (https://developers.google.com/workspace/chat/authenticate-authorize-chat-app). NOTIFICATION_TYPE_FORCE_NOTIFY = 2 # Do not notify recipients, and do not mark the message as unread. # This behaves similarly to the user muting the conversation or enabling # [Chat Do Not Disturb](https://support.google.com/chat/answer/9093489). # # Requires [app authentication] # (https://developers.google.com/workspace/chat/authenticate-authorize-chat-app). NOTIFICATION_TYPE_SILENT = 3 end end |