Class: Google::Apps::Chat::V1::CustomStatus
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::CustomStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/availability.rb
Overview
Represents a user's custom status in Google Chat. This includes a short text message with an optional emoji that a user sets to give more context about their availability.
Instance Attribute Summary collapse
-
#emoji ⇒ ::Google::Apps::Chat::V1::Emoji
Required.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
The timestamp when the custom status expires.
-
#text ⇒ ::String
Required.
-
#ttl ⇒ ::Google::Protobuf::Duration
Input only.
Instance Attribute Details
#emoji ⇒ ::Google::Apps::Chat::V1::Emoji
Returns Required. The emoji of the custom status. Only Unicode emojis are supported; custom emojis are not supported.
96 97 98 99 |
# File 'proto_docs/google/chat/v1/availability.rb', line 96 class CustomStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expire_time ⇒ ::Google::Protobuf::Timestamp
Returns The timestamp when the custom status expires.
Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.
96 97 98 99 |
# File 'proto_docs/google/chat/v1/availability.rb', line 96 class CustomStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::String
Returns Required. The text of the custom status. This will be a string with maximum length of 64.
96 97 98 99 |
# File 'proto_docs/google/chat/v1/availability.rb', line 96 class CustomStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ttl ⇒ ::Google::Protobuf::Duration
Returns Input only. The time-to-live duration after which the custom status expires.
Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
96 97 98 99 |
# File 'proto_docs/google/chat/v1/availability.rb', line 96 class CustomStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |