Class: Google::Apps::Chat::V1::FindGroupChatsRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::FindGroupChatsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
A request to get group chat spaces based on user resources.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#space_view ⇒ ::Google::Apps::Chat::V1::SpaceView
Requested space view type.
-
#users ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of spaces to return. The service might return fewer than this value.
If unspecified, at most 10 spaces are returned.
The maximum value is 30. If you use a value more than 30, it's automatically changed to 30.
Negative values return an INVALID_ARGUMENT error.
588 589 590 591 |
# File 'proto_docs/google/chat/v1/space.rb', line 588 class FindGroupChatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous call to find group chats. Provide this parameter to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the token. Passing different values may lead to unexpected results.
588 589 590 591 |
# File 'proto_docs/google/chat/v1/space.rb', line 588 class FindGroupChatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#space_view ⇒ ::Google::Apps::Chat::V1::SpaceView
Returns Requested space view type. If unset, defaults to
SPACE_VIEW_RESOURCE_NAME_ONLY. Requests that specify
SPACE_VIEW_EXPANDED must include scopes that allow reading space data,
for example,
https://www.googleapis.com/auth/chat.spaces or
https://www.googleapis.com/auth/chat.spaces.readonly.
588 589 590 591 |
# File 'proto_docs/google/chat/v1/space.rb', line 588 class FindGroupChatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#users ⇒ ::Array<::String>
Returns Optional. Resource names of all human users in group chat with the calling user. Chat apps can't be included in the request.
The maximum number of users that can be specified in a single request is
49.
Format: users/{user}, where {user} is either the id for the
person from the
People API, or the id for the
user
in the Directory API. For example, to find all group chats with the calling
user and two other users, with People API profile IDs 123456789 and
987654321, you can use users/123456789 and users/987654321.
You can also use the email as an alias for {user}. For example,
users/example@gmail.com where example@gmail.com is the email of the
Google Chat user.
588 589 590 591 |
# File 'proto_docs/google/chat/v1/space.rb', line 588 class FindGroupChatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |