Class: Google::Apps::Chat::V1::FindGroupChatsResponse
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::FindGroupChatsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
A response containing group chat spaces with exactly the calling user and the requested users.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that you can send as
pageTokento retrieve the next page of results. -
#spaces ⇒ ::Array<::Google::Apps::Chat::V1::Space>
List of spaces in the requested (or first) page.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that you can send as pageToken to retrieve the next page of
results. If empty, there are no subsequent pages.
602 603 604 605 |
# File 'proto_docs/google/chat/v1/space.rb', line 602 class FindGroupChatsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#spaces ⇒ ::Array<::Google::Apps::Chat::V1::Space>
Returns List of spaces in the requested (or first) page.
602 603 604 605 |
# File 'proto_docs/google/chat/v1/space.rb', line 602 class FindGroupChatsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |