Class: Google::Apps::Chat::V1::GetAvailabilityRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::GetAvailabilityRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/availability.rb
Overview
Request message for the GetAvailability method.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The resource name of the availability to retrieve.
Format: users/{user}/availability
{user} is the id for the Person in the People API or Admin SDK directory
API. For example, users/123456789.
The user's email address or me can also be used as an alias to refer to
the caller. For example, users/user@example.com or users/me.
124 125 126 127 |
# File 'proto_docs/google/chat/v1/availability.rb', line 124 class GetAvailabilityRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |