Class: Google::Apps::Chat::V1::GetMessageRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::GetMessageRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
Request to get a message.
Instance Attribute Summary collapse
-
#markup_syntax ⇒ ::Google::Apps::Chat::V1::MarkupSyntax
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#markup_syntax ⇒ ::Google::Apps::Chat::V1::MarkupSyntax
Returns Optional. Specifies the desired output syntax for the Chat message
formatted_text field.
487 488 489 490 |
# File 'proto_docs/google/chat/v1/message.rb', line 487 class GetMessageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Resource name of the message.
Format: spaces/{space}/messages/{message}
If you've set a custom ID for your message, you can use the value from the
clientAssignedMessageId field for {message}. For details, see [Name a
message]
(https://developers.google.com/workspace/chat/create-messages#name_a_created_message).
487 488 489 490 |
# File 'proto_docs/google/chat/v1/message.rb', line 487 class GetMessageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |