Class: Google::Apps::Chat::V1::ListSectionItemsRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::ListSectionItemsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/section.rb
Overview
Request message for listing section items.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A query filter.
Currently only supports filtering by space.
For example, space = spaces/{space}.
Invalid queries are rejected with an INVALID_ARGUMENT error.
287 288 289 290 |
# File 'proto_docs/google/chat/v1/section.rb', line 287 class ListSectionItemsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Optional. The maximum number of section items to return. The service may return fewer than this value.
If unspecified, at most 10 section items will be returned.
The maximum value is 100. If you use a value more than 100, it's automatically changed to 100.
Negative values return an INVALID_ARGUMENT error.
287 288 289 290 |
# File 'proto_docs/google/chat/v1/section.rb', line 287 class ListSectionItemsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous list section items call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
287 288 289 290 |
# File 'proto_docs/google/chat/v1/section.rb', line 287 class ListSectionItemsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which is the section resource name that owns this collection of section items. Only supports listing section items for the calling user.
When you're filtering by space, use the wildcard - to search across all
sections. For example, users/{user}/sections/-.
Format: users/{user}/sections/{section}.
287 288 289 290 |
# File 'proto_docs/google/chat/v1/section.rb', line 287 class ListSectionItemsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |