Class: Google::Apps::Chat::V1::ListSectionItemsResponse
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::ListSectionItemsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/section.rb
Overview
Response message for listing section items.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#section_items ⇒ ::Array<::Google::Apps::Chat::V1::SectionItem>
The section items from the specified section.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page. If
this field is omitted, there are no subsequent pages.
300 301 302 303 |
# File 'proto_docs/google/chat/v1/section.rb', line 300 class ListSectionItemsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#section_items ⇒ ::Array<::Google::Apps::Chat::V1::SectionItem>
Returns The section items from the specified section.
300 301 302 303 |
# File 'proto_docs/google/chat/v1/section.rb', line 300 class ListSectionItemsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |