Class: Google::Apps::Chat::V1::MarkAsActiveRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::MarkAsActiveRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/availability.rb
Overview
Request message for the MarkAsActive method.
Instance Attribute Summary collapse
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
The absolute timestamp when the ACTIVE state expires.
-
#name ⇒ ::String
Required.
-
#ttl ⇒ ::Google::Protobuf::Duration
The duration from the current time until the ACTIVE state expires.
Instance Attribute Details
#expire_time ⇒ ::Google::Protobuf::Timestamp
Returns The absolute timestamp when the ACTIVE state expires.
Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.
165 166 167 168 |
# File 'proto_docs/google/chat/v1/availability.rb', line 165 class MarkAsActiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the availability to mark as active. Format: users/{user}/availability
{user} is the id for the Person in the People API or Admin SDK directory
API. For example, users/123456789.
The user's email address or me can also be used as an alias to refer to
the caller. For example, users/user@example.com or users/me.
165 166 167 168 |
# File 'proto_docs/google/chat/v1/availability.rb', line 165 class MarkAsActiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ttl ⇒ ::Google::Protobuf::Duration
Returns The duration from the current time until the ACTIVE state expires. Using a short TTL can effectively reset the user's state to be based on activity after this brief duration.
Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
165 166 167 168 |
# File 'proto_docs/google/chat/v1/availability.rb', line 165 class MarkAsActiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |