Module: Google::Apps::Chat::V1::MarkupSyntax
- Defined in:
- proto_docs/google/chat/v1/markup_syntax.rb
Overview
Specifies the markup syntax used to format the Chat message text.
Applies to the text field of the Message resource.
Constant Summary collapse
- MARKUP_SYNTAX_UNSPECIFIED =
Represents the unspecified value.
0- MARKUP_SYNTAX_CHAT =
Uses Google Chat's markup syntax. See https://developers.google.com/workspace/chat/format-messages#format-texts for more information.
1- MARKUP_SYNTAX_MARKDOWN =
Uses Markdown syntax. This syntax is based on the CommonMark specification, with additional extensions. See https://developers.google.com/workspace/chat/format-messages#format-texts for more information.
2