Module: Google::Apps::Chat::V1::Membership::Affiliation
- Defined in:
- proto_docs/google/chat/v1/membership.rb
Overview
Represents the affiliation of a user to the Google Workspace organization that owns the space. This enum may have more values added in the future.
Constant Summary collapse
- AFFILIATION_UNSPECIFIED =
Default value. This value is unused.
0- INTERNAL =
An account managed by the same Google Workspace organization that owns the space.
1- EXTERNAL =
An account external to the Google Workspace organization that owns the space (e.g., a consumer account, or an account managed by a different Workspace organization).
2- MANAGED_EXTERNAL =
An account managed by the Workspace organization that owns the space, but provisioned for a user who is external to the organization (e.g., a Guest user). To learn more about guests, see https://support.google.com/chat/answer/16997417.
3