Class: Google::Apps::Chat::V1::MessagePin
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::MessagePin
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message_pin.rb
Overview
A pin on a Chat message. For more information see Pin a message.
Instance Attribute Summary collapse
-
#message ⇒ ::String
Required.
-
#name ⇒ ::String
Identifier.
Instance Attribute Details
#message ⇒ ::String
Returns Required. Immutable. The resource name of the message that is pinned.
Format: spaces/{space}/messages/{message}.
38 39 40 41 |
# File 'proto_docs/google/chat/v1/message_pin.rb', line 38 class MessagePin include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the message pin.
Format: spaces/{space}/messagePins/{message_pin}
The resource ID component matches the resource ID component of the
message. For example, a message with spaces/AAA/messages/bbb.ccc
corresponds to the message pin with the resource name
spaces/AAA/messagePins/bbb.ccc.
38 39 40 41 |
# File 'proto_docs/google/chat/v1/message_pin.rb', line 38 class MessagePin include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |