Class: Google::Apps::Chat::V1::PositionSectionRequest
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::PositionSectionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/section.rb
Overview
Request message for positioning a section.
Defined Under Namespace
Modules: Position
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#relative_position ⇒ ::Google::Apps::Chat::V1::PositionSectionRequest::Position
Optional.
-
#sort_order ⇒ ::Integer
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The resource name of the section to position.
Format: users/{user}/sections/{section}.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'proto_docs/google/chat/v1/section.rb', line 222 class PositionSectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The position of the section. module Position # Unspecified position. POSITION_UNSPECIFIED = 0 # Start of the list of sections. START = 1 # End of the list of sections. const_set :END, 2 end end |
#relative_position ⇒ ::Google::Apps::Chat::V1::PositionSectionRequest::Position
Returns Optional. The relative position of the section in the list of sections.
Note: The following fields are mutually exclusive: relative_position, sort_order. If a field in that set is populated, all other fields in the set will automatically be cleared.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'proto_docs/google/chat/v1/section.rb', line 222 class PositionSectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The position of the section. module Position # Unspecified position. POSITION_UNSPECIFIED = 0 # Start of the list of sections. START = 1 # End of the list of sections. const_set :END, 2 end end |
#sort_order ⇒ ::Integer
Returns Optional. The absolute position of the section in the list of sections. The position must be greater than 0. If the position is greater than the number of sections, the section will be appended to the end of the list. This operation inserts the section at the given position and shifts the original section at that position, and those below it, to the next position.
Note: The following fields are mutually exclusive: sort_order, relative_position. If a field in that set is populated, all other fields in the set will automatically be cleared.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'proto_docs/google/chat/v1/section.rb', line 222 class PositionSectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The position of the section. module Position # Unspecified position. POSITION_UNSPECIFIED = 0 # Start of the list of sections. START = 1 # End of the list of sections. const_set :END, 2 end end |