Class: Google::Apps::Chat::V1::QuotedMessageMetadata
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::QuotedMessageMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/message.rb
Overview
Information about a message that another message quotes.
When you create a message, you can quote messages within the same thread, or quote a root message to create a new root message. However, you can't quote a message reply from a different thread.
When you update a message, you can't add or replace the
quotedMessageMetadata field, but you can remove it.
For example usage, see Quote another message.
Defined Under Namespace
Modules: QuoteType
Instance Attribute Summary collapse
-
#forwarded_metadata ⇒ ::Google::Apps::Chat::V1::ForwardedMetadata
readonly
Output only.
-
#last_update_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#name ⇒ ::String
Required.
-
#quote_type ⇒ ::Google::Apps::Chat::V1::QuotedMessageMetadata::QuoteType
Optional.
-
#quoted_message_snapshot ⇒ ::Google::Apps::Chat::V1::QuotedMessageSnapshot
readonly
Output only.
Instance Attribute Details
#forwarded_metadata ⇒ ::Google::Apps::Chat::V1::ForwardedMetadata (readonly)
Returns Output only. Metadata about the source space of the quoted message. Populated only for FORWARD quote type.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/chat/v1/message.rb', line 285 class QuotedMessageMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The quote type of the quoted message. module QuoteType # Reserved. This value is unused. QUOTE_TYPE_UNSPECIFIED = 0 # If quote_type is `REPLY`, you can do the following: # # * If you're replying in a thread, you can quote another message in that # thread. # # * If you're creating a root message, you can quote another root message # in that space. # # You can't quote a message reply from a different thread. REPLY = 1 end end |
#last_update_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. The timestamp when the quoted message was created or when the quoted message was last updated.
If the message was edited, use this field, last_update_time.
If the message was never edited, use create_time.
If last_update_time doesn't match the latest version of the quoted
message, the request fails.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/chat/v1/message.rb', line 285 class QuotedMessageMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The quote type of the quoted message. module QuoteType # Reserved. This value is unused. QUOTE_TYPE_UNSPECIFIED = 0 # If quote_type is `REPLY`, you can do the following: # # * If you're replying in a thread, you can quote another message in that # thread. # # * If you're creating a root message, you can quote another root message # in that space. # # You can't quote a message reply from a different thread. REPLY = 1 end end |
#name ⇒ ::String
Returns Required. Resource name of the message that is quoted.
Format: spaces/{space}/messages/{message}.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/chat/v1/message.rb', line 285 class QuotedMessageMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The quote type of the quoted message. module QuoteType # Reserved. This value is unused. QUOTE_TYPE_UNSPECIFIED = 0 # If quote_type is `REPLY`, you can do the following: # # * If you're replying in a thread, you can quote another message in that # thread. # # * If you're creating a root message, you can quote another root message # in that space. # # You can't quote a message reply from a different thread. REPLY = 1 end end |
#quote_type ⇒ ::Google::Apps::Chat::V1::QuotedMessageMetadata::QuoteType
Returns Optional. Specifies the quote type. If not set, defaults to REPLY in the message read/write path for backward compatibility.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/chat/v1/message.rb', line 285 class QuotedMessageMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The quote type of the quoted message. module QuoteType # Reserved. This value is unused. QUOTE_TYPE_UNSPECIFIED = 0 # If quote_type is `REPLY`, you can do the following: # # * If you're replying in a thread, you can quote another message in that # thread. # # * If you're creating a root message, you can quote another root message # in that space. # # You can't quote a message reply from a different thread. REPLY = 1 end end |
#quoted_message_snapshot ⇒ ::Google::Apps::Chat::V1::QuotedMessageSnapshot (readonly)
Returns Output only. A snapshot of the quoted message's content.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/chat/v1/message.rb', line 285 class QuotedMessageMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The quote type of the quoted message. module QuoteType # Reserved. This value is unused. QUOTE_TYPE_UNSPECIFIED = 0 # If quote_type is `REPLY`, you can do the following: # # * If you're replying in a thread, you can quote another message in that # thread. # # * If you're creating a root message, you can quote another root message # in that space. # # You can't quote a message reply from a different thread. REPLY = 1 end end |