Class: Google::Apps::Chat::V1::SearchSpacesResponse
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::SearchSpacesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
Response with a list of spaces corresponding to the search spaces request.
Defined Under Namespace
Classes: SearchSpaceResult
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that can be used to retrieve the next page.
-
#results ⇒ ::Array<::Google::Apps::Chat::V1::SearchSpacesResponse::SearchSpaceResult>
readonly
Output only.
-
#spaces ⇒ ::Array<::Google::Apps::Chat::V1::Space>
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#total_size ⇒ ::Integer
The total number of spaces that match the query, across all pages.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages.
Only populated when useAdminAccess is set to true.
987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'proto_docs/google/chat/v1/space.rb', line 987 class SearchSpacesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A single result item from a space search. # @!attribute [r] space # @return [::Google::Apps::Chat::V1::Space] # Output only. The matched space. class SearchSpaceResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#results ⇒ ::Array<::Google::Apps::Chat::V1::SearchSpacesResponse::SearchSpaceResult> (readonly)
Returns Output only. The list of search results that matched the query.
987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'proto_docs/google/chat/v1/space.rb', line 987 class SearchSpacesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A single result item from a space search. # @!attribute [r] space # @return [::Google::Apps::Chat::V1::Space] # Output only. The matched space. class SearchSpaceResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#spaces ⇒ ::Array<::Google::Apps::Chat::V1::Space>
This field is deprecated and may be removed in the next major version update.
Returns Deprecated: Please use the new results field instead.
A page of the requested spaces. This field will be populated only when
useAdminAccess is set to true and deprecated in favor of the new
results field.
987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'proto_docs/google/chat/v1/space.rb', line 987 class SearchSpacesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A single result item from a space search. # @!attribute [r] space # @return [::Google::Apps::Chat::V1::Space] # Output only. The matched space. class SearchSpaceResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#total_size ⇒ ::Integer
Returns The total number of spaces that match the query, across all pages. If the result is over 10,000 spaces, this value is an estimate.
Only populated when useAdminAccess is set to true.
987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'proto_docs/google/chat/v1/space.rb', line 987 class SearchSpacesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A single result item from a space search. # @!attribute [r] space # @return [::Google::Apps::Chat::V1::Space] # Output only. The matched space. class SearchSpaceResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |