Class: Google::Apps::Chat::V1::Space::AccessPermissionSettings
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::Space::AccessPermissionSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
Access permission settings for a space.
Instance Attribute Summary collapse
-
#discover_space_setting ⇒ ::Google::Apps::Chat::V1::Space::AccessPermissionSetting
Optional.
-
#join_space_setting ⇒ ::Google::Apps::Chat::V1::Space::AccessPermissionSetting
Optional.
-
#view_space_membership_setting ⇒ ::Google::Apps::Chat::V1::Space::AccessPermissionSetting
Optional.
Instance Attribute Details
#discover_space_setting ⇒ ::Google::Apps::Chat::V1::Space::AccessPermissionSetting
Returns Optional. Access permission setting for discovering the space.
312 313 314 315 |
# File 'proto_docs/google/chat/v1/space.rb', line 312 class AccessPermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#join_space_setting ⇒ ::Google::Apps::Chat::V1::Space::AccessPermissionSetting
Returns Optional. Access permission setting for joining the space.
312 313 314 315 |
# File 'proto_docs/google/chat/v1/space.rb', line 312 class AccessPermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view_space_membership_setting ⇒ ::Google::Apps::Chat::V1::Space::AccessPermissionSetting
Returns Optional. Access permission setting for viewing space membership.
Must be specified together with
PermissionSettings.view_space_membership in the update mask and request
body when updating who can view space membership. When granting view
access to a target audience, you must also grant
PermissionSettings.view_space_membership to all members in the same
request. To remove an existing target audience (for example, to restrict
view access to space managers or assistant managers only), specify an
empty AccessPermissionSetting (with no principals).
312 313 314 315 |
# File 'proto_docs/google/chat/v1/space.rb', line 312 class AccessPermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |