Class: Google::Apps::Chat::V1::Space::PermissionSettings
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::Space::PermissionSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/space.rb
Overview
Permission settings that you can specify when updating an existing named space.
To set permission settings when creating a space, specify the
PredefinedPermissionSettings field in your request.
Instance Attribute Summary collapse
-
#manage_apps ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#manage_members_and_groups ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#manage_webhooks ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#modify_space_details ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#post_messages ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
readonly
Output only.
-
#reply_messages ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#toggle_history ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#use_at_mention_all ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
-
#view_space_membership ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Optional.
Instance Attribute Details
#manage_apps ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for managing apps in a space.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#manage_members_and_groups ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for managing members and groups in a space.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#manage_webhooks ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for managing webhooks in a space.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#modify_space_details ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for updating space name, avatar, description and guidelines.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#post_messages ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting (readonly)
Returns Output only. Setting for posting messages in a space.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reply_messages ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for replying to messages in a space.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toggle_history ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for toggling space history on and off.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_at_mention_all ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for using @all in a space.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view_space_membership ⇒ ::Google::Apps::Chat::V1::Space::PermissionSetting
Returns Optional. Setting for viewing space membership.
Must be specified together with
AccessPermissionSettings.view_space_membership_setting in the update
mask and request body when updating who can view space membership.
When restricting view access to specific roles (for example, space
managers or assistant managers only), specify the desired role
permissions here and provide an empty
AccessPermissionSettings.view_space_membership_setting in the same
request. If a target audience is configured in
AccessPermissionSettings.view_space_membership_setting, this setting
must be granted to all members.
378 379 380 381 |
# File 'proto_docs/google/chat/v1/space.rb', line 378 class PermissionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |