Class: Google::Apps::Chat::V1::WidgetMarkup::FormAction
- Inherits:
-
Object
- Object
- Google::Apps::Chat::V1::WidgetMarkup::FormAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/chat/v1/widgets.rb
Overview
A form action describes the behavior when the form is submitted. For example, you can invoke Apps Script to handle the form.
Defined Under Namespace
Classes: ActionParameter
Instance Attribute Summary collapse
-
#action_method_name ⇒ ::String
The method name is used to identify which part of the form triggered the form submission.
-
#parameters ⇒ ::Array<::Google::Apps::Chat::V1::WidgetMarkup::FormAction::ActionParameter>
List of action parameters.
Instance Attribute Details
#action_method_name ⇒ ::String
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'proto_docs/google/chat/v1/widgets.rb', line 227 class FormAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of string parameters to supply when the action method is invoked. # For example, consider three snooze buttons: snooze now, snooze one day, # snooze next week. You might use `action method = snooze()`, passing the # snooze type and snooze time in the list of string parameters. # @!attribute [rw] key # @return [::String] # The name of the parameter for the action script. # @!attribute [rw] value # @return [::String] # The value of the parameter. class ActionParameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parameters ⇒ ::Array<::Google::Apps::Chat::V1::WidgetMarkup::FormAction::ActionParameter>
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'proto_docs/google/chat/v1/widgets.rb', line 227 class FormAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of string parameters to supply when the action method is invoked. # For example, consider three snooze buttons: snooze now, snooze one day, # snooze next week. You might use `action method = snooze()`, passing the # snooze type and snooze time in the list of string parameters. # @!attribute [rw] key # @return [::String] # The name of the parameter for the action script. # @!attribute [rw] value # @return [::String] # The value of the parameter. class ActionParameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |